========
Credits
========

Core Development Team
---------------------

* Eleftherios Garyfallidis, Indiana University, IN, USA
* Marc-Alexandre Côté, Microsoft Research, Montreal, QC, CA
* David Reagan, Indiana University, IN, USA
* Ranveer Aggarwal, Microsoft, Hyderabad, Telangana, India
* Serge Koudoro, Indiana University, IN, USA
* Karandeep Singh Juneja, India

Contributors
------------

* Ariel Rokem, University of Washington, WA, USA
* Matthew Brett, Birmingham University, Birmingham, UK
* Yaroslav Halchenko
* Kesshi jordan

See:  `CONTRIBUTING.rst <contributing_link.html>`_
